Module cache_tools

Module cache_tools 

Model-boundary result-cache integration for MCP transports.

Structs

CachedResultsConfig
Configuration for model-boundary cached result envelopes.
CachedResultsTransport
MCP transport wrapper that caches oversized array results at the model-facing boundary.

Constants

CACHE_PAGE_TOOL
Default registry name for the cached result page tool.
CACHE_RELEASE_TOOL
Default registry name for the cached result release tool.

Functions

cache_page_tool
Build a tool that returns a page from a cached result handle.
cache_release_tool
Build a tool that releases a cached result handle.
cache_tools
Build the default cached-result page and release tools.
register_cache_tools
Register the default cached-result page and release tools into registry.