pub fn cache_release_tool(cache: Arc<dyn ResultCache>) -> Arc<dyn Tool>Expand description
Build a tool that releases a cached result handle.
pub fn cache_release_tool(cache: Arc<dyn ResultCache>) -> Arc<dyn Tool>Build a tool that releases a cached result handle.