CachedResultsConfig

Struct CachedResultsConfig 

pub struct CachedResultsConfig {
    pub threshold_bytes: usize,
    pub page_size: usize,
}
Configuration for model-boundary cached result envelopes.

Fields

threshold_bytes: usize

Minimum serialized array size before a result is cached.

page_size: usize

Number of items exposed in the first page and default follow-up pages.

Implementations

Source

impl CachedResultsConfig

pub fn new(threshold_bytes: usize) -> Self

Build a config with an explicit size threshold and otherwise default page settings.

pub fn with_page_size(self, page_size: usize) -> Self

Set the page size used for first-page and follow-up slices.