Model-boundary result-cache integration for MCP transports.
Structs
- Cached
Results Config - Configuration for model-boundary cached result envelopes.
- Cached
Results Transport - MCP transport wrapper that caches oversized array results at the model-facing boundary.
Constants
- CACHE_
PAGE_ TOOL - Default registry name for the cached result page tool.
- CACHE_
RELEASE_ TOOL - Default registry name for the cached result release tool.
Functions
- cache_
page_ tool - Build a tool that returns a page from a cached result handle.
- cache_
release_ tool - Build a tool that releases a cached result handle.
- cache_
tools - Build the default cached-result page and release tools.
- register_
cache_ tools - Register the default cached-result page and release tools into
registry.